@@ -6,8 +6,8 @@ class TestDOMHTMLPreElement (TestCase):
 
     @min_os_level('10.6')
     def testMehods10_6(self):
-        self.failUnlessResultIsBOOL(DOMHTMLPreElement.wrap)
-        self.failUnlessArgIsBOOL(DOMHTMLPreElement.setWrap_, 0)
+        self.assertResultIsBOOL(DOMHTMLPreElement.wrap)
+        self.assertArgIsBOOL(DOMHTMLPreElement.setWrap_, 0)
 
 if __name__ == "__main__":
     main()
