@@ -4,7 +4,7 @@ from WebKit import *
 
 class TestDOMTreeWalker (TestCase):
     def testMethods(self):
-        self.failUnlessResultIsBOOL(DOMTreeWalker.expandEntityReferences)
+        self.assertResultIsBOOL(DOMTreeWalker.expandEntityReferences)
 
 if __name__ == "__main__":
     main()
